from brevisurl.tests.test_brevisurl import *
from brevisurl.tests.test_utils import *
from brevisurl.tests.test_views import *
from brevisurl.tests.test_models import *
from brevisurl.tests.backends.test_local import *
from brevisurl.tests.templatetags.test_brevisurltags import *